==> flutter_firebase_basic_tools-0.0.20.tar.gz: lib/widgets/pricing_container_item.dart <==
import 'package:flutter_firebase_basic_tools/widgets/background_image_with_gradient_color.dart';
import 'package:flutter_firebase_basic_tools/widgets/covered_container_coming_soon.dart';
import 'package:flutter/material.dart';

class PricingContainerItem extends StatefulWidget {
  const PricingContainerItem({
    @required this.title,
    @required this.description,
    @required this.characteristics,
    @required this.icon,
    @required this.color,
    @required this.imageUrl,
    @required this.gradientColor1,
    @required this.gradientColor2,
    @required this.comingSoon,
    @required this.function,
  });

  final String title;
  final String description;
  final String characteristics;
  final IconData icon;
  final Color color;
  final String imageUrl;
  final Color gradientColor1;
  final Color gradientColor2;
  final bool comingSoon;
  final Function function;

  @override
  _PricingContainerItemState createState() => _PricingContainerItemState();
}

class _PricingContainerItemState extends State<PricingContainerItem> {
  @override
  Widget build(BuildContext context) {
    return FractionallySizedBox(
      heightFactor: 0.9,
      child: CoveredContainerComingSoon(
        enableCover: widget.comingSoon,
        child: Card(
          elevation: 5,
          child: BackgroundImageWithGradientColor(
            height: MediaQuery.of(context).size.height,
            width: MediaQuery.of(context).size.width,
            boxFit: BoxFit.fitHeight,
            backgroundImagePath: widget.imageUrl,
            linearGradient: LinearGradient(
                begin: FractionalOffset.topCenter,
                end: FractionalOffset.bottomCenter,
                colors: [
                  widget.gradientColor1,
                  widget.gradientColor2,
                ],
                stops: [
                  0.8,
                  1.0
                ]),
            child: Container(
              child: Center(
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: <Widget>[
                    Spacer(flex: 18),
                    Text(
                      widget.title,
                      textAlign: TextAlign.center,
                      style: TextStyle(
                        color: widget.color,
                        fontSize: 24,
                        fontWeight: FontWeight.bold,
                        fontStyle: FontStyle.italic,
                      ),
                    ),
                    Spacer(flex: 1),
                    RichText(
                      text: TextSpan(
                        style: DefaultTextStyle.of(context).style,
                        children: <TextSpan>[
                          TextSpan(
                            text: widget.description.substring(0, 2),
                            style: TextStyle(
                              fontWeight: FontWeight.bold,
                              color: widget.color,
                              fontSize: 36,
                            ),
                          ),
                          TextSpan(
                            text: widget.description.substring(
                              2,
                              widget.description.length,
                            ),
                            style: TextStyle(
                              color: widget.color,
                              fontSize: 36,
                            ),
                          ),
                        ],
                      ),
                    ),
                    Spacer(flex: 1),
                    RichText(
                      text: TextSpan(
                        style: DefaultTextStyle.of(context).style,
                        children: <TextSpan>[
                          TextSpan(
                            text: widget.characteristics.substring(0, 1),
                            style: TextStyle(
                              fontWeight: FontWeight.bold,
                              color: widget.color,
                              fontSize: 24,
                            ),
                          ),
                          TextSpan(
                            text: widget.characteristics.substring(
                              1,
                              widget.characteristics.length,
                            ),
                            style: TextStyle(
                              color: widget.color,
                              fontSize: 24,
                            ),
                          ),
                        ],
                      ),
                    ),
                    Spacer(flex: 1),
                    RaisedButton(
                      onPressed: () {
                        widget.function();
                      },
                      elevation: 0,
                      color: Colors.transparent,
                      shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(5),
                        side: BorderSide(
                          color: Colors.white,
                        ),
                      ),
                      child: Text(
                        'Buy Now',
                        style: TextStyle(
                          color: widget.color,
                        ),
                      ),
                    ),
                    Spacer(flex: 2),
                  ],
                ),
              ),
            ),
          ),
        ),
      ),
    );
  }
}

==> flutter_firebase_basic_tools-0.0.96.tar.gz: lib/widgets/pricing_container_item.dart <==
import 'package:flutter_firebase_basic_tools/widgets/background_image_with_gradient_color.dart';
import 'package:flutter_firebase_basic_tools/widgets/covered_container_coming_soon.dart';
import 'package:flutter/material.dart';

class PricingContainerItem extends StatefulWidget {
  const PricingContainerItem({
    @required this.title,
    @required this.description,
    @required this.characteristics,
    @required this.icon,
    @required this.textColor,
    @required this.imageUrl,
    @required this.gradientColor1,
    @required this.gradientColor2,
    @required this.comingSoon,
    @required this.function,
  });

  final String title;
  final String description;
  final String characteristics;
  final IconData icon;
  final Color textColor;
  final String imageUrl;
  final Color gradientColor1;
  final Color gradientColor2;
  final bool comingSoon;
  final Function function;

  @override
  _PricingContainerItemState createState() => _PricingContainerItemState();
}

class _PricingContainerItemState extends State<PricingContainerItem> {
  @override
  Widget build(BuildContext context) {
    return FractionallySizedBox(
      heightFactor: 0.9,
      child: CoveredContainerComingSoon(
        enableCover: widget.comingSoon,
        child: Card(
          elevation: 5,
          child: BackgroundImageWithGradientColor(
            height: MediaQuery.of(context).size.height,
            width: MediaQuery.of(context).size.width,
            boxFit: BoxFit.fitHeight,
            backgroundImagePath: widget.imageUrl,
            linearGradient: LinearGradient(
                begin: FractionalOffset.topCenter,
                end: FractionalOffset.bottomCenter,
                colors: [
                  widget.gradientColor1,
                  widget.gradientColor2,
                ],
                stops: [
                  0.8,
                  1.0
                ]),
            child: Container(
              child: Center(
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: <Widget>[
                    Spacer(flex: 18),
                    Text(
                      widget.title,
                      textAlign: TextAlign.center,
                      style: TextStyle(
                        color: widget.textColor,
                        fontSize: 24,
                        fontWeight: FontWeight.bold,
                        fontStyle: FontStyle.italic,
                      ),
                    ),
                    Spacer(flex: 1),
                    RichText(
                      text: TextSpan(
                        style: DefaultTextStyle.of(context).style,
                        children: <TextSpan>[
                          TextSpan(
                            text: widget.description.substring(0, 2),
                            style: TextStyle(
                              fontWeight: FontWeight.bold,
                              color: widget.textColor,
                              fontSize: 36,
                            ),
                          ),
                          TextSpan(
                            text: widget.description.substring(
                              2,
                              widget.description.length,
                            ),
                            style: TextStyle(
                              color: widget.textColor,
                              fontSize: 36,
                            ),
                          ),
                        ],
                      ),
                    ),
                    Spacer(flex: 1),
                    RichText(
                      text: TextSpan(
                        style: DefaultTextStyle.of(context).style,
                        children: <TextSpan>[
                          TextSpan(
                            text: widget.characteristics.substring(0, 1),
                            style: TextStyle(
                              fontWeight: FontWeight.bold,
                              color: widget.textColor,
                              fontSize: 24,
                            ),
                          ),
                          TextSpan(
                            text: widget.characteristics.substring(
                              1,
                              widget.characteristics.length,
                            ),
                            style: TextStyle(
                              color: widget.textColor,
                              fontSize: 24,
                            ),
                          ),
                        ],
                      ),
                    ),
                    Spacer(flex: 1),
                    RaisedButton(
                      onPressed: () {
                        widget.function();
                      },
                      elevation: 0,
                      color: Colors.transparent,
                      shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(5),
                        side: BorderSide(
                          color: Colors.white,
                        ),
                      ),
                      child: Text(
                        'Buy Now',
                        style: TextStyle(
                          color: widget.textColor,
                        ),
                      ),
                    ),
                    Spacer(flex: 2),
                  ],
                ),
              ),
            ),
          ),
        ),
      ),
    );
  }
}
